@@ -13,6 +13,22 @@ def grade_command(config, canvas, args):
       webbrowser.open(submissions.speedgrader(submission))
   else:
     for submission in submission_list:
+      if args.verbose:
+        id = f"{submission.assignment.course.course_code} " \
+             f"{submission.assignment.name} {submission.user}"
+
+        event = ""
+        try:
+          event += f" grade = {args.grade}"
+        except:
+          pass
+        try:
+          event += f" msg = '{args.message}'"
+        except:
+          pass
+
+        print(f"{id}:{event}")
+
       submission.edit(**results)
 
 def add_command(subp):
@@ -31,3 +47,7 @@ def add_command(subp):
     help="The grade to set for the submissions")
   grade_options.add_argument("-m", "--message",
     help="A comment to the student")
+  grade_parser.add_argument("-v", "--verbose",
+    action="store_true", default=False,
+    help="Increases verbosity, prints what grade is set "
+         "for which assignment for which student.")
