@@ -263,10 +263,20 @@ def get_uid(user):
   raise AttributeError(f"no unique user attribute existed, tried: {attributes}")
 def add_user_option_wo_depends(parser, required=False):
   """
-  Adds the -u option to argparse parser,
-  without adding other required options
+  Adds the -u option to argparse parser, without adding
+  other required options.
+
+  The `role` option allows specifying which roles to include, for instance 
+  students or TAs.
   """
-  help="Filter users on name, login ID or Canvas ID by user_regex"
+  help="Filter users on Canvas ID, name, login ID, integration ID, or " \
+       "SIS ID by user_regex. " \
+       "Integration ID and SIS ID match exactly, not by regex. " \
+       "Note that for login ID, you should start with ^ and $ to avoid " \
+       "matching on unintended substrings; c.f. son@institution.tld and " \
+       "person@institution.tld, where the first will match both without " \
+       "leading ^. The regex allows matching using ^son@, thus skipping " \
+       "any domain in this case."
   options = {"required": required}
   if not required:
     options["default"] = ".*"
@@ -277,6 +287,12 @@ def add_user_option_wo_depends(parser, required=False):
   parser.add_argument("-u", "--user", metavar="user_regex",
     help=help, **options)
 
+  parser.add_argument("-r", "--role",
+    choices={"teacher", "student", "student_view",
+             "ta", "observer", "designer"},
+    default="student",
+    help="Includes only users in this role, defaults to student.")
+
 def add_user_option(parser, required=False):
   """Adds the -u option to argparse parser"""
   try:
@@ -289,7 +305,8 @@ def process_user_option(canvas, args):
   """Processes the user option from command line, returns a list of users"""
   return list(filter_users(
     courses.process_course_option(canvas, args),
-    args.user))
+    args.user,
+    roles=args.role))
 def add_group_category_option_wo_depends(parser):
   """Adds the group category option, without adding required other options"""
   parser.add_argument("-C", "--category", metavar="category_regex",
@@ -318,7 +335,7 @@ def add_group_option_wo_depends(parser):
 
   parser.add_argument("-G", "--group", metavar="group_regex",
     required=False,
-    help="Filters groups whose name match group_regex")
+    help="Filters user groups whose name match group_regex")
 
 def add_group_option(parser):
   """Adds group filtering options to argparse parser,
