@@ -38,6 +38,15 @@ def make_classes_comparable():
       if obj_name in CANVASAPI_CLASSES[module_name]:
         canvas_comparable(obj)
         canvas_hashable(obj)
+def make_useful_user_dunder_str():
+  """Improves the user class by changing __str__"""
+  def name_and_login(self):
+    try:
+      return f"{self.name} <{self.login_id}>"
+    except AttributeError as err:
+      return f"{self.name} <>"
+  import canvasapi.user
+  canvasapi.user.User.__str__ = name_and_login
 
 # Loads all hacks
 this_module = sys.modules[__name__]
